==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-lang-sqlpp/src/main/java/org/apache/asterix/lang/sqlpp/rewrites/SqlppStatementRewriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.sqlpp.rewrites;

import org.apache.asterix.common.exceptions.CompilationException;
import org.apache.asterix.lang.common.base.IStatementRewriter;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.sqlpp.visitor.SqlppDeleteRewriteVisitor;

class SqlppStatementRewriter implements IStatementRewriter {

    @Override
    public void rewrite(Statement stmt) throws CompilationException {
        rewriteDeleteStatement(stmt);
    }

    private void rewriteDeleteStatement(Statement stmt) throws CompilationException {
        if (stmt != null) {
            SqlppDeleteRewriteVisitor visitor = new SqlppDeleteRewriteVisitor();
            stmt.accept(visitor, null);
        }
    }
}

==> apache-asterixdb-0.9.4.1-source-release.zip: apache-asterixdb-0.9.4.1/asterix-lang-sqlpp/src/main/java/org/apache/asterix/lang/sqlpp/rewrites/SqlppStatementRewriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.lang.sqlpp.rewrites;

import org.apache.asterix.common.exceptions.CompilationException;
import org.apache.asterix.lang.common.base.IStatementRewriter;
import org.apache.asterix.lang.common.base.Statement;
import org.apache.asterix.lang.sqlpp.util.SqlppVariableUtil;
import org.apache.asterix.lang.sqlpp.visitor.SqlppDeleteRewriteVisitor;

class SqlppStatementRewriter implements IStatementRewriter {

    @Override
    public void rewrite(Statement stmt) throws CompilationException {
        rewriteDeleteStatement(stmt);
    }

    private void rewriteDeleteStatement(Statement stmt) throws CompilationException {
        if (stmt != null) {
            SqlppDeleteRewriteVisitor visitor = new SqlppDeleteRewriteVisitor();
            stmt.accept(visitor, null);
        }
    }

    @Override
    public String toExternalVariableName(String statementParameterName) {
        return SqlppVariableUtil.toExternalVariableName(statementParameterName);
    }
}
